@@ -75,6 +75,18 @@ describe 'oslo::cache' do
           :tag    => 'openstack',
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-pylibmc')
+        end
+      end
     end
 
     context 'with memcache backend' do
@@ -87,11 +99,22 @@ describe 'oslo::cache' do
       it 'configures cache backend' do
         is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcache')
         is_expected.to contain_package('python-memcache').with(
-          :ensure => 'present',
           :name   => platform_params[:python_memcache_package_name],
           :tag    => ['openstack'],
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-memcache')
+        end
+      end
     end
 
     context 'with string in list parameters' do
